@@ -369,17 +369,18 @@ from abc import ABC, abstractmethod
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
-from ae.base import NAME_PARTS_SEP, duplicates, now_str, snake_to_camel                             # type: ignore
-from ae.files import RegisteredFile                                                                 # type: ignore
-from ae.paths import copy_file, copy_tree, norm_path, path_folders, Collector, FilesRegister        # type: ignore
-from ae.updater import check_all                                                                    # type: ignore
-from ae.inspector import stack_var                                                                  # type: ignore
-from ae.i18n import default_language, load_language_texts, register_translations_path               # type: ignore
-from ae.core import DEBUG_LEVELS, registered_app_names                                              # type: ignore
-from ae.console import ConsoleApp                                                                   # type: ignore
+from ae.base import NAME_PARTS_SEP, duplicates, now_str, snake_to_camel                                 # type: ignore
+from ae.files import RegisteredFile                                                                     # type: ignore
+from ae.paths import (                                                                                  # type: ignore
+    add_common_storage_paths, copy_file, copy_tree, norm_path, path_folders, Collector, FilesRegister)
+from ae.updater import check_all                                                                        # type: ignore
+from ae.inspector import stack_var                                                                      # type: ignore
+from ae.i18n import default_language, load_language_texts, register_translations_path                   # type: ignore
+from ae.core import DEBUG_LEVELS, registered_app_names                                                  # type: ignore
+from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.61'
+__version__ = '0.1.62'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -648,7 +649,9 @@ class MainAppBase(ConsoleApp, ABC):
         self._start_event_loop: Optional[Callable]          #: callable to start event loop of GUI framework
         self._stop_event_loop: Optional[Callable]           #: callable to start event loop of GUI framework
 
-        self.flow_path = list()  # init for Literal type recognition - will be overwritten by setup_app_states()
+        self.flow_path = list()     # init for Literal type recognition - will be overwritten by setup_app_states()
+
+        add_common_storage_paths()  # determine platform specific path placeholders, like e.g. {pictures}, {downloads}..
 
         super().__init__(**console_app_kwargs)
 
